==> netpanzer_0.8.orig.tar.gz: netpanzer-0.8/src/NetPanzer/Views/Components/ViewGlobals.hpp <==
/*
Copyright (C) 1998 Pyrosoft Inc. (www.pyrosoftgames.com), Matthew Bogue
 
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
 
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __ViewGlobals_hpp__
#define __ViewGlobals_hpp__

#include <stdint.h>

#define topLeftBorderColor           (Color::white)
#define bottomRightBorderColor       (Color::black)

#define componentBodyColor           (Color::terreVerte)
#define componentTextColor           (Color::black)
#define componentInActiveTextColor   (Color::black)
#define componentActiveTextColor     (Color::red)
#define componentFocusTextColor      (Color::white)

#define activeWindowTitleTextColor   (Color::white)
#define activeWindowTitleBodyColor   (Color::terreVerte)
#define inactiveWindowTitleTextColor (Color::black)
#define inactiveWindowTitleBodyColor (Color::terreVerte)

extern uint8_t gForeground;
extern uint8_t gBackground;

void setForeground(uint8_t color);
void setBackground(uint8_t color);

#endif // end __ViewGlobals_hpp__

==> netpanzer_0.8.2.orig.tar.gz: netpanzer-0.8.2/src/NetPanzer/Views/Components/ViewGlobals.hpp <==
/*
Copyright (C) 1998 Pyrosoft Inc. (www.pyrosoftgames.com), Matthew Bogue
 
This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.
 
This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.
 
You should have received a copy of the GNU General Public License
along with this program; if not, write to the Free Software
Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#ifndef __ViewGlobals_hpp__
#define __ViewGlobals_hpp__

#include "SDL.h"

#define topLeftBorderColor           (Color::white)
#define bottomRightBorderColor       (Color::black)

#define componentBodyColor           (Color::terreVerte)
#define componentTextColor           (Color::black)
#define componentInActiveTextColor   (Color::black)
#define componentActiveTextColor     (Color::red)
#define componentFocusTextColor      (Color::white)

#define activeWindowTitleTextColor   (Color::white)
#define activeWindowTitleBodyColor   (Color::terreVerte)
#define inactiveWindowTitleTextColor (Color::black)
#define inactiveWindowTitleBodyColor (Color::terreVerte)

extern Uint8 gForeground;
extern Uint8 gBackground;

void setForeground(Uint8 color);
void setBackground(Uint8 color);

#endif // end __ViewGlobals_hpp__
